@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::DateModules::Overhead;
 
-our $VERSION = 0.003; # VERSION
+our $VERSION = 0.004; # VERSION
 
 our $results = [
   [
@@ -8,81 +8,81 @@ our $results = [
     "OK",
     [
       {
-        errors => 0.00013,
-        mod_overhead_time => 54.9,
+        errors => 0.00053,
+        mod_overhead_time => 60.7,
         participant => "DateTime::Duration",
         proc_private_dirty_size => 1,
-        proc_rss_size => 4.4,
+        proc_rss_size => 4.5,
         proc_size => 16,
         samples => 20,
-        time => 61,
+        time => 65,
         vs_slowest => 1,
       },
       {
-        errors => 8.9e-05,
-        mod_overhead_time => 54.9,
+        errors => 0.00016,
+        mod_overhead_time => 55.7,
         participant => "DateTime",
         proc_private_dirty_size => 11,
         proc_rss_size => 15,
         proc_size => 44,
         samples => 20,
-        time => 61,
-        vs_slowest => 1,
+        time => 60,
+        vs_slowest => 1.1,
       },
       {
-        errors => 2.3e-05,
-        mod_overhead_time => 12.9,
+        errors => 2.1e-05,
+        mod_overhead_time => 12.7,
         participant => "Time::Piece",
-        proc_private_dirty_size => 0.83,
-        proc_rss_size => 4.2,
+        proc_private_dirty_size => 0.82,
+        proc_rss_size => 4.1,
         proc_size => 16,
-        samples => 20,
-        time => 19,
-        vs_slowest => 3.3,
+        samples => 21,
+        time => 17,
+        vs_slowest => 3.8,
       },
       {
-        errors => 4.4e-05,
-        mod_overhead_time => 7.9,
+        errors => 0.00016,
+        mod_overhead_time => 5.7,
+        participant => "Time::Moment",
+        proc_private_dirty_size => 2,
+        proc_rss_size => 5,
+        proc_size => 20,
+        samples => 20,
+        time => 10,
+        vs_slowest => 5,
+      },
+      {
+        errors => 2.7e-05,
+        mod_overhead_time => 7.7,
         participant => "Time::Local",
         proc_private_dirty_size => 2.3,
         proc_rss_size => 5.9,
         proc_size => 19,
         samples => 20,
-        time => 14,
-        vs_slowest => 4.4,
-      },
-      {
-        errors => 3.7e-05,
-        mod_overhead_time => 5.9,
-        participant => "Time::Moment",
-        proc_private_dirty_size => 1.5,
-        proc_rss_size => 5.1,
-        proc_size => 17,
-        samples => 20,
         time => 12,
-        vs_slowest => 5.1,
+        vs_slowest => 5.3,
       },
       {
-        errors => 2.4e-05,
+        errors => 2.5e-05,
         mod_overhead_time => 3.9,
         participant => "DateTime::Tiny",
         proc_private_dirty_size => 1.4,
         proc_rss_size => 4.8,
         proc_size => 19,
         samples => 20,
-        time => 10,
-        vs_slowest => 6.1,
+        time => 8.2,
+        vs_slowest => 7.9,
       },
       {
-        errors => 1.8e-05,
+        errors => 6.2e-06,
         mod_overhead_time => 0,
         participant => "perl -e1 (baseline)",
         proc_private_dirty_size => 11,
         proc_rss_size => 15,
         proc_size => 44,
         samples => 20,
-        time => 6.1,
-        vs_slowest => 10,
+        time => 4.3,
+        vs_slowest => 15,
       },
     ],
     {
@@ -206,7 +206,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2789.226,
+                                              speed                        => 2600.007,
                                               stepping                     => 4,
                                             },
                                             {
@@ -321,7 +321,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2601.265,
+                                              speed                        => 2865.734,
                                               stepping                     => 4,
                                             },
                                             {
@@ -436,7 +436,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2599.953,
+                                              speed                        => 2600.007,
                                               stepping                     => 4,
                                             },
                                             {
@@ -551,11 +551,11 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2600.007,
+                                              speed                        => 2754.281,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 4.53969597816467,
+      "func.elapsed_time"              => 4.74987506866455,
       "func.module_startup"            => 1,
       "func.module_versions"           => {
                                             "__PACKAGE__"                              => "1.040",
@@ -602,9 +602,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1503796297,
       "func.scenario_module_sha1sum"   => "5ebfd278d72fa0753b8f1f5cf1309d768ec11d6e",
       "func.scenario_module_sha256sum" => "f8df64a57fc589ecb08bf12173acec12e29ff2ff1768b099eba1a06cf7f6809e",
-      "func.time_end"                  => 1503796335.50459,
+      "func.time_end"                  => 1503798512.62551,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1503796330.96489,
+      "func.time_start"                => 1503798507.87563,
       "table.field_aligns"             => [
                                             "left",
                                             "left",
